#
#  Copyright (c) 2008 INdT - Instituto Nokia de Tecnologia
#
#  This file is part of python-purple.
#
#  python-purple is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  python-purple is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

cimport purple

cdef extern from *:
    ctypedef char const_char "const char"

cdef class Account:
    """ Account class """
    cdef account.PurpleAccount *__account
    cdef plugin.PurplePlugin *c_plugin
    cdef prpl.PurplePluginProtocolInfo *c_prpl_info
    cdef plugin.PurplePluginInfo *c_plugin_info

    cdef savedstatuses.PurpleSavedStatus *__sstatus

    def __init__(self, char *username, char *protocol_id):
        self.__account = account.c_purple_account_new(username, protocol_id)
        self.c_plugin = plugin.c_purple_plugins_find_with_id(protocol_id)
        self.c_prpl_info = plugin.c_PURPLE_PLUGIN_PROTOCOL_INFO(self.c_plugin)


    def set_password(self, password):
        account.c_purple_account_set_password(self.__account, password)

    def set_enabled(self, ui, value):
        account.c_purple_account_set_enabled(self.__account, ui, value)

    def get_acc_username(self):
        if self.__account:
            return account.c_purple_account_get_username(self.__account)

    def get_password(self):
        if self.__account:
            return account.c_purple_account_get_password(self.__account)

    def set_status(self):
        self.__sstatus = savedstatuses.c_purple_savedstatus_new(NULL, status.PURPLE_STATUS_AVAILABLE)
        savedstatuses.c_purple_savedstatus_activate(self.__sstatus)

    def get_buddies_online(self):
        cdef glib.GSList *iter
        cdef blist.PurpleBuddy *buddy
        buddies = []
        iter = blist.c_purple_find_buddies(self.__account, NULL)
        while iter:
            buddy = <blist.PurpleBuddy *> iter.data
            if <blist.PurpleBuddy *>buddy and \
                account.c_purple_account_is_connected(blist.c_purple_buddy_get_account(buddy)) and \
                status.c_purple_presence_is_online(blist.c_purple_buddy_get_presence(buddy)):
                buddies += [buddy.name]
            iter = iter.next
        return buddies

    def get_proxyinfo(self):
        cdef proxy.PurpleProxyInfo *c_proxyinfo
        c_proxyinfo = account.c_purple_account_get_proxy_info(self.__account)
        if c_proxyinfo == NULL:
            return None
        cdef ProxyInfo proxyinfo
        proxyinfo = proxy.ProxyInfo()
        proxyinfo.c_proxyinfo = c_proxyinfo
        return proxyinfo

    def set_proxyinfo(self, ProxyInfo proxyinf):
        account.c_purple_account_set_proxy_info(self.__account, proxyinf.c_proxyinfo)

    def get_protocol_options(self):
        ''' FIXME: It is just a hack, to set the XMPP's options. '''
        cdef glib.GList *iter
        cdef account.PurpleAccountOption *option
        cdef prefs.PurplePrefType type
        cdef const_char *label_name
        cdef const_char *str_value
        cdef const_char *setting
        cdef int int_value
        cdef glib.gboolean bool_value
        iter = self.c_prpl_info.protocol_options
        while iter:
            option = <account.PurpleAccountOption *> iter.data
            type = account.c_purple_account_option_get_type(option)
            label_name = account.c_purple_account_option_get_text(option)
            setting = account.c_purple_account_option_get_setting(option)
            if type == prefs.PURPLE_PREF_STRING:
                str_value = account.c_purple_account_option_get_default_string(option)

                # Google Talk default domain hackery!
                if str_value == NULL and str(<char *> label_name) == "Connect server":
                    str_value = "talk.google.com"

                if self.__account != NULL:
                    str_value = account.c_purple_account_get_string(self.__account, setting, str_value)
                    account.c_purple_account_set_string(self.__account, setting, str_value );

            elif type == prefs.PURPLE_PREF_INT:
                int_value = account.c_purple_account_option_get_default_int(option)
                if self.__account != NULL:
                   int_value = account.c_purple_account_get_int(self.__account, setting, int_value)
                   if str(<char *> setting) == "port":
                        account.c_purple_account_set_int(self.__account, setting, 443);

            elif type == prefs.PURPLE_PREF_BOOLEAN:
                bool_value = account.c_purple_account_option_get_default_bool(option)
                if self.__account != NULL:
                    bool_value = account.c_purple_account_get_bool(self.__account, setting, bool_value)
                    if str(<char *> setting) == "old_ssl":
                        account.c_purple_account_set_bool(self.__account, setting, True);

            elif type == prefs.PURPLE_PREF_STRING_LIST:
                str_value = account.c_purple_account_option_get_default_list_value(option)
                if self.__account != NULL:
                    str_value = account.c_purple_account_get_string(self.__account, setting, str_value)

            iter = iter.next

